// Next.js API route support: https://nextjs.org/docs/api-routes/introduction
import type { NextApiRequest, NextApiResponse } from "next";
import { LAWS_BLOCK_ID } from "../../config";
import { notion } from "../../lib/notion";

interface Topic {
  blockId: string;
  name: string;
}

function getTopicsInDatabase(notionResp: any): Topic[] {
  return notionResp.results.map((block: any) => ({
    blockId: block.id,
    name: block.properties.Name.title[0].plain_text,
  }));
}

export default async function handler(
  req: NextApiRequest,
  res: NextApiResponse<Topic[]>
) {
  const resp = await notion.databases.query({
    database_id: LAWS_BLOCK_ID,
    sorts: [
      {
        property: "Created",
        direction: "ascending",
      },
    ],
  });
  res.status(200).json(getTopicsInDatabase(resp));
}
